package com.pokkt.demo.fragments;


import android.app.Fragment;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioButton;
import android.widget.RadioGroup;

import com.pokkt.PokktAds;
import com.pokkt.ad.demo.R;
import com.pokkt.nexagemraid.PokktAssetManager;
import com.pokkt.sdk.AdConfig;
import com.pokkt.sdk.PokktAdActivity;
import com.pokkt.sdk.adnetworks.AdFormat;
import com.pokkt.sdk.adnetworks.AdNetwork;
import com.pokkt.sdk.adnetworks.AdNetworkInfo;
import com.pokkt.sdk.adnetworks.S2SAdNetwork;
import com.pokkt.sdk.banners.PokktBannerView;
import com.pokkt.sdk.models.adcampaign.AdCampaign;
import com.pokkt.sdk.models.adcampaign.AdCampaignFactory;
import com.pokkt.sdk.models.adcampaign.JsonAdCampaign;
import com.pokkt.sdk.models.adcampaign.VastAdCampaign;
import com.pokkt.sdk.net.GetAdTask;
import com.pokkt.sdk.net.GetHTMLTask;
import com.pokkt.sdk.utils.CommonUtils;
import com.pokkt.sdk.utils.PokktStorage;
import com.pokkt.sdk.utils.ToastMessageHelper;

public class PlayWithTagFragment extends BaseFragment {

    private RadioGroup rad_group_ad_types, rad_group_ad_input_format_types, rad_group_ad_response_types;
    private EditText edt_tag;
    private Button btn_reset, btn_request;
    private PokktBannerView pokkt_banner_view;
    private int selectedAdFormatType = 0;
    private int selectedAdInputFormatType = 0;
    private int selectedAdResponseType = 0;

    private AdConfig adConfig;
    private AdNetwork adNetwork;

    public PlayWithTagFragment() {
        // Required empty public constructor
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        return inflater.inflate(R.layout.fragment_play_with_tag, container, false);
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {

        rad_group_ad_types = view.findViewById(R.id.rad_group_ad_types);
        rad_group_ad_input_format_types = view.findViewById(R.id.rad_group_ad_input_format_types);
        rad_group_ad_response_types = view.findViewById(R.id.rad_group_ad_response_types);
        edt_tag = view.findViewById(R.id.edt_tag);
        btn_reset = (Button) findView(findView(view, R.id.btn_reset), R.id.button);
        btn_request = (Button) findView(findView(view, R.id.btn_request), R.id.button);
        pokkt_banner_view = view.findViewById(R.id.pokkt_banner_view);

        // click listeners
        btn_reset.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // if banner is checked thn call destroy banner and clear edtTag.
                edt_tag.setText("");
                if (selectedAdFormatType == 3) {
                    PokktAds.Banner.destroy(pokkt_banner_view);
                }
            }
        });
        btn_request.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {

                String tagValue = edt_tag.getText().toString();

                // create adNetwork and adConfig

                AdNetworkInfo networkInfo;
                adConfig = new AdConfig();

                if(selectedAdFormatType == 0){ // video
                    networkInfo = new AdNetworkInfo("POKKT", "", "S2S", "31", "");
                    networkInfo.setAdFormat(AdFormat.VIDEO.getValue());
                    adConfig.adFormat = AdFormat.VIDEO;
                }else if(selectedAdFormatType == 1){ // interstitial
                    networkInfo = new AdNetworkInfo("POKKT", "", "S2S", "32", "");
                    networkInfo.setAdFormat(AdFormat.INTERSTITIAL.getValue());
                    adConfig.adFormat = AdFormat.INTERSTITIAL;
                }else{ // banner
                    networkInfo = new AdNetworkInfo("POKKT", "", "S2S", "33", "");
                    networkInfo.setAdFormat(AdFormat.BANNER.getValue());
                    adConfig.adFormat = AdFormat.BANNER;
                }
                networkInfo.setNetworkType(3); // 1 and 3  = POKKT
                networkInfo.setResponseFormat(selectedAdResponseType);

                adNetwork = new S2SAdNetwork();
                adNetwork.initNetwork(getActivity(), networkInfo);

                adConfig.isRewarded = true;
                adConfig.screenName = "DemoScreenApp";

                 if(selectedAdInputFormatType == 0) {
                    // create ad campaign and open ad activity
                    try {
                        AdCampaign adCampaign = AdCampaignFactory.getAdCampaignFromResponse(tagValue.trim(),
                                getActivity(),
                                adNetwork.getAdNetworkInfo(),
                                adConfig);
                        openAd(adCampaign);
                    } catch (Exception e) {
                        e.printStackTrace();
                        ToastMessageHelper.showToast(getActivity(), e.toString());
                    }
                }else if (selectedAdInputFormatType == 1) {
                    //send this url to pokkt sdk
                    adNetwork.getAdNetworkInfo().setRequestUrl(tagValue.trim());
                    new GetAdTask(getActivity(), adNetwork, adConfig, new GetAdTask.GetAdTaskDelegate() {
                        @Override
                        public void onSuccess(AdCampaign adCampaign) {
                            openAd(adCampaign);
                        }

                        @Override
                        public void onFailure(String errorMessage) {
                            ToastMessageHelper.showToast(getActivity(), errorMessage);
                        }
                    }).submitSerial();
                } else {
                     try {
                         JsonAdCampaign adCampaign = new JsonAdCampaign(2);
                         adCampaign.setInterstitialBaseUrl("https://www.pokkt.com");
                         adCampaign.setInterstitialCreative(edt_tag.getText().toString());
                         Intent intent = new Intent(getActivity(), PokktAdActivity.class);
                         intent.putExtra("AD_CAMPAIGN", adCampaign);
                         intent.putExtra("AD_CONFIG", adConfig);
                         intent.putExtra("AD_NETWORK_INFO", adNetwork.getAdNetworkInfo());
                         intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP | Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_NEW_TASK);
                         startActivity(intent);
                     } catch (Exception e) {
                         e.printStackTrace();
                     }
                 }
            }
        });

        // radio-group ad types
        rad_group_ad_types.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int checkedId) {
                RadioButton checkedButton = group.findViewById(checkedId);
                String checkButtonText = checkedButton.getText().toString();
                if ("VIDEO".equals(checkButtonText)) {
                    selectedAdFormatType = 0;
                } else if ("INTERSTITIAL".equals(checkButtonText)) {
                    selectedAdFormatType = 1;
                } else {
                    selectedAdFormatType = 2;
                }
            }
        });

        // radio-group input types
        rad_group_ad_input_format_types.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int checkedId) {
                RadioButton checkedButton = group.findViewById(checkedId);
                String checkButtonText = checkedButton.getText().toString();
                if ("JSON / VAST".equals(checkButtonText)) {
                    selectedAdInputFormatType = 0;
                } else if("URL".equals(checkButtonText)){
                    selectedAdInputFormatType = 1;
                }else {
                    selectedAdInputFormatType = 2;
                }
            }
        });

        // radio-group response types
        rad_group_ad_response_types.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int checkedId) {
                RadioButton checkedButton = group.findViewById(checkedId);
                String checkButtonText = checkedButton.getText().toString();
                if ("JSON".equals(checkButtonText)) {
                    selectedAdResponseType = 0;
                } else {
                    selectedAdResponseType = 1;
                }
            }
        });

        // download MRAID
        if (!CommonUtils.hasValue(PokktAssetManager.MRAID_JS)) {
            GetHTMLTask getHTMLTask = new GetHTMLTask(getActivity(), PokktStorage.getStore(getActivity()).getMRAIDPath(), new GetHTMLTask.GetHTMLTaskDelegate() {
                @Override
                public void onSuccess(String result) {
                    PokktAssetManager.MRAID_JS = result;
                }

                @Override
                public void onFailure(String errorMessage) {

                }
            });
            getHTMLTask.submitSerial();
        }

        //dummyData();

        // set fonts
        setFont(edt_tag);
        setFont(btn_reset);
        setFont(btn_request);
        setFont(rad_group_ad_response_types.getChildAt(0));
        setFont(rad_group_ad_response_types.getChildAt(1));
        setFont(rad_group_ad_types.getChildAt(0));
        setFont(rad_group_ad_types.getChildAt(1));
        setFont(rad_group_ad_types.getChildAt(2));
        setFont(rad_group_ad_types);
        setFont(view.findViewById(R.id.txt_ad_format_heading));
        setFont(view.findViewById(R.id.txt_ad_response_heading));

        //set Texts
        btn_reset.setText(getString(R.string.txt_btn_reset));
        btn_request.setText(getString(R.string.txt_btn_request));
        Toolbar toolbar = (Toolbar) view.findViewById(R.id.pokkttoolbar);
        toolbar.setNavigationOnClickListener(new View.OnClickListener(){
            @Override
            public void onClick(View view) {
                getActivity().onBackPressed();
            }
        });
        super.onViewCreated(view, savedInstanceState);
    }

    private void openAd(AdCampaign adCampaign) {

        Intent intent = new Intent(getActivity(), PokktAdActivity.class);
        //intent.putExtra("isCaching", true);
        //intent.putExtra("IS_SHOWCASE_APP", true);
        //intent.putExtra("isShowCaseApp", true);
        intent.putExtra("AD_CAMPAIGN", adCampaign);
        intent.putExtra("AD_CONFIG", adConfig);
        intent.putExtra("AD_NETWORK_INFO", adNetwork.getAdNetworkInfo());
        intent.setFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP | Intent.FLAG_ACTIVITY_SINGLE_TOP | Intent.FLAG_ACTIVITY_NEW_TASK);
        startActivity(intent);
    }

    private void dummyData() {
        String TAG_URL = "https://rawgit.com/InteractiveAdvertisingBureau/VAST_Samples/master/VAST%201-2.0%20Samples/Inline_NonLinear_Verification_VAST2.0.xml";

        String TAG_RESPONSE = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n" +
                "<VAST version=\"2.0\"><Ad id=\"105423687-1cc70.0803c.de68\" ><InLine><AdSystem version=\"1.0\">SpotXchange</AdSystem><AdTitle><![CDATA[In-Stream Video]]></AdTitle><Description><![CDATA[]]></Description><Error><![CDATA[https://search.spotxchange.com/exception?_a=224046&_p=1cc70.0803c.de68&_z=1&_m=eNpNT2tPGzEQNH%2FFn8nh99mR%2BoEqQULKg0ICSqvIcuw1d4TcRXc5FRHy21snQS0r7UqenfXMiIwQhBCVTEhFc8IQKKUgUCNyRygF7UQUNARNQeWEkBwxJohQ6HaCKJOZMRmTMqMJWXVVeIX%2B1dWv67s7%2B30%2BGYyGS7THXQuNfe7KgPtYm0hX3HMWA6HcKAI%2BgOQ%2BCa28cwFfnullayv4nQ4S4Ot6XYIN9caVVYJacI0vsnZb79584apnyHy9SUTXhRIqD%2FYkxbz2JrrQE4RA7xil54D7Hk3iMjJyDIMPiNJc5wxdoMl8NDoPiv6k%2BgKcxh7HOiXE%2FV3TwSUObudwf4%2FPqW27qxvomtckfIr%2FMJveD%2B38frQ8Gttu7SfvZE1xpZg0afMPtYVri7RyTEYDmjnDuGaQ09wJLQVhimoVSfx6c9T6%2F%2FUSHw6f%2Fj%2FGm8f14v1mMx5MXn7Obul0di2mgzVP72LxNOSLl4VM%2FTae%2Ffj2F3dFmJM%3D&_l=eNptjltLw0AQhfe37LOks0k2uyn4JpRCk1K12vQlTHYnGtu0IRfsxf53E4sgKsOch3M%2BOEcwwWT%2Fgg1ijAIHNHjGsRTov8Y0ZsAs4banz9zj4zPPCsvHvKdABJLf8AqP%2B679tnxPDmZT0e4X1mXbwqR0MK%2B4e6E0J%2FrKhQboY9PV2JJNS6w31FZbNPQPCx7wy4XFy9nsKv2sh2rfrq4gG5Z0GTlmX466huqRQZt19VE2LdbFzhbI0JJGRJmFUvo6U0blrgd%2BHshAuQJypsCVLAgHFaCF9OFaJYTSyv3RDf2JwPe98GP%2BvICkXLrzu6fN%2BjGR88lSRqfFMZokELnRe%2FJ2X8an6LAup7efWAJqWQ%3D%3D&_t=eNo9UW1v2jAQzm%2FxZwQJjaCLtA90sKobCWgradmYLMe%2BNC4htmyHBbr9954Dqj88z909vhefoeOgnVRNAJNpORVFHE9ZGEVwy%2BIyjoS4jVAIw3Aa8IrJJlDmhTWSB%2FCR%2BEYKYFw11J00kIR8KGRAdM1OTh58eILuUQpQ9MhqKWgpjXW0NKxXUWSC2pN1cCDJGzGu8MRrCY2jFvNIEg6IbbVWxlmKl6UgiTMtYFktSfKb5OvZwxwL9Uy%2F%2FUQzXceIX5c54tPiLkWazb70oZ7S9Y3HeIa4uvf4Y%2FV9g%2FSYY%2F4fbMgr6AdUGhocio7pGOUSQNDW1ChUzmmb7Ea7USHF8GUoVFvUgIPz%2FbABtxt1RQG9uBtZrVx3WYsrlTlcnkErZiuSNG1d%2Fx8QwRzDss93%2BD50LTDDK2o1cL8QzfzCHBjrPQFHycFb0DlPfQN6CVOm9fVPrqUPSkB98QZE2WscTxBEwzAMss1yGUSTOL759G%2F7uujS%2B1xmZ7H%2FNd%2BM08f93%2B04q9LX9LyaL7rtOa%2Byp4cuO6ef3wFmT71B&_b=eNozZfAL9fFBI2r8QzxNolwiK%2FxDkkF0VZS7W5ZfladJZJavkV94VK6%2Fi6exX4hTpr97qC0AcfcToA%3D%3D&beacon_type=exception&exception%5Bid%5D=%24EXCEPTION_ID&exception%5Bdata%5D=%24EXCEPTION_DATA&exception%5Btrace%5D=%24EXCEPTION_TRACE&syn%5Btiming%5D=%24TIMING_DATA]]></Error><Impression><![CDATA[https://search.spotxchange.com/beacon?_a=224046&_p=1cc70.0803c.de68&_z=1&_m=eNpNT2tPGzEQNH%2FFn8nh99mR%2BoEqQULKg0ICSqvIcuw1d4TcRXc5FRHy21snQS0r7UqenfXMiIwQhBCVTEhFc8IQKKUgUCNyRygF7UQUNARNQeWEkBwxJohQ6HaCKJOZMRmTMqMJWXVVeIX%2B1dWv67s7%2B30%2BGYyGS7THXQuNfe7KgPtYm0hX3HMWA6HcKAI%2BgOQ%2BCa28cwFfnullayv4nQ4S4Ot6XYIN9caVVYJacI0vsnZb79584apnyHy9SUTXhRIqD%2FYkxbz2JrrQE4RA7xil54D7Hk3iMjJyDIMPiNJc5wxdoMl8NDoPiv6k%2BgKcxh7HOiXE%2FV3TwSUObudwf4%2FPqW27qxvomtckfIr%2FMJveD%2B38frQ8Gttu7SfvZE1xpZg0afMPtYVri7RyTEYDmjnDuGaQ09wJLQVhimoVSfx6c9T6%2F%2FUSHw6f%2Fj%2FGm8f14v1mMx5MXn7Obul0di2mgzVP72LxNOSLl4VM%2FTae%2Ffj2F3dFmJM%3D&_l=eNptjltLw0AQhfe37LOks0k2uyn4JpRCk1K12vQlTHYnGtu0IRfsxf53E4sgKsOch3M%2BOEcwwWT%2Fgg1ijAIHNHjGsRTov8Y0ZsAs4banz9zj4zPPCsvHvKdABJLf8AqP%2B679tnxPDmZT0e4X1mXbwqR0MK%2B4e6E0J%2FrKhQboY9PV2JJNS6w31FZbNPQPCx7wy4XFy9nsKv2sh2rfrq4gG5Z0GTlmX466huqRQZt19VE2LdbFzhbI0JJGRJmFUvo6U0blrgd%2BHshAuQJypsCVLAgHFaCF9OFaJYTSyv3RDf2JwPe98GP%2BvICkXLrzu6fN%2BjGR88lSRqfFMZokELnRe%2FJ2X8an6LAup7efWAJqWQ%3D%3D&_t=eNo9UVGT0jAQ7m%2FJMwNpqfQI4wPnnQwqBfUOBXEyaZPS3LVNJkkRBvnvblo1D%2Fvtfrv7ZbPJBMtVE4hJUiQ8i%2BOE4TAUdywu4pDzuxASGOMkyEsmm0CZI2tkHmR91xX1DnUXLRBB1jHj0ADpil2crD01gfAkuVD0xCrJaSGNdbQwrMtCknFqL9aJGpErMi7zkFdSNI5a6EMED5BttVbGWQrFkiPiTCtAVktEfqDtZr58AKEO6Yev4K42Mdj3n7Zgvz3erwDm83cd1cFqM%2FY2noNdL7z9sv74DPC0hf6fcGFeim5ApUUDQ9GIRpAuhOC0NRUkSue0JYfRYZRJPjwOuWqzSsDg%2BeuwEe4wOmeZ6JKHkdXKnfu1uEKZun8GLZktEWnaqroNEGeOgez3e3gfhFYwk5fUapH7hWjmF%2BaEsT7i4iRz4T1xdh66C2hPU6b13%2F%2BIQKhWXFTdEhX04hucIAiHGAeMJORqyYSgY6UyVqGZJHjWEVrBT%2F4nxgTJmvloHCeT6RSomKBcuovnomSKo77NiKNUzT8yBDKBOtU2znSlIR73cryXw7NbEE7ieDz9vV6kL%2Fv6OU6j3a%2B0Xp5Xi8c36cvreV%2Bn1S5K5f7h82X%2FtK130fLtH%2Bjs2NA%3D&_b=eNozYPAL9fFBI2r8qiINfbNCDSOr%2FHJ8s7IrI41CTXyNIk0jQ5LLI7MCjf3cA6v8w8OyfXMDbQF9gxRO&beacon_type=start&aid=2c8c9fad-400e-11e8-ae3c-132f5f200007&syn%5Btiming%5D=%24TIMING_DATA]]></Impression><Impression><![CDATA[https://googleads4.g.doubleclick.net/pcs/view?xai=AKAOjss6Kj4Be6menMHYjkn-DWS6YofT3A4D-GlgZJSquwYeIxlpnWSF2c-NhbwKi8AozY-gR3umnnBCZZkcFOYhOo4mZ4T23D7YRGL5fiQTApLdG5qmzHORtVTpeataKE1l_YDY3VT6IYNtNN4EZRWatAYh6B9oT6lzGOoHM2q5X1A_ORil8z2B2AnI2hnDYwo3kkh1ft2PltxKNnVMejw-X1wBsTAUuz143Y_VrEf2pSrECj74NBscOX1b9ldSiauu3rvuiXz8de3ICID-9PDynnL69qHc9ChdMNYLoIrUaPPVaDIOt9cYmZKVmfS4r5KfWED8-J6HsZZhUULuMLH4CwTzkdDqndnukFw1hQmRT6Pa44CfrtoSOTPXAiOn8axbMAW95TicGyW_AFYRYcCPcpCoC73CxtEuEbEKO9KXhmRDoS3NTQwK0f9T7S1-D3gGZZ6eBoZhV1FMpSz0s8SrLjdW_ivWP8sJdJHut1ErprFswDbpVEtDI9ur39dzq6SIgLM5VdeJdBaTeQRAzhP_k0Qeso2_ufQfAjSlT2jrmsPKM_fbNsQpmojMp8KuqapLCeCvkL93BTpdhGc_TICf8R6Sd9O4lm4fxnX7vs5qNtAqi9TtKe2djvhsOr7eJmqM7gnpnOhyXohZCfXLrRd8iiY4aadYN3FxLEVDfkh39ySCbCBkNMFHkDL9TfF5TEZCSRFTLILme-HnIZ6Pi7X2vzvCuk8k8ipCufbZGq0gk3lU3sHErx6ucrElagBgMYNnKaXcRm3NrlTBpIO4ixAb&sai=AMfl-YQf-TmpUAFCvDB98OzSpOCoIiZc6O5pfhUIq7Ff4ishvDkRpfgiWbgkk8rX71gHjLWfWwXz3sr1eRJyNKf8NgBNs8-xj8MwVqvQEkY90SFxiTow6CM6BryfCQ&sig=Cg0ArKJSzCFX4UjS41FpEAE&pr=21:0.9608&urlfix=1&adurl=]]></Impression><Impression><![CDATA[https://googleads.g.doubleclick.net/xbbe/pixel?d=CMSBQhDr52cYx8aiMiABMAE&v=APEucNXsK9U4TwaH70UYkiR4g8c6l2ERtmgvjhXkc6RasVNQktUT5iJS90X2Spk_9L06lY46jrA2WBTXSOA-265ohql6MFY4sQ]]></Impression><Impression><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=11;]]></Impression><Impression><![CDATA[https://sync.search.spotxchange.com/audience_sync/9?spotx_push=1&spotx_audience_id=2c8c9fad-400e-11e8-ae3c-132f5f200007&redir=https%3A%2F%2Fbeacon.krxd.net%2Fusermatch.gif%3Fpartner%3Dspotxchange%26partner_uid%3D2c8c9fad-400e-11e8-ae3c-132f5f200007]]></Impression><Impression><![CDATA[https://event.spotxchange.com/vast/impression?_x=WzE1MjQ1NjE3MDIsImU2NjZlZDE5NDdhMDExZThhNGY0MWRkODFlNjcwMDA3IiwiMjI0MDQ2IiwiMWNjNzAuMDgwM2MuZGU2OCIsIjcwMjUiLCIxY2M3MC4wODAzYy5kZTY4IiwiMTA1NDIzNjg3IiwiMmM4YzlmYWQtNDAwZS0xMWU4LWFlM2MtMTMyZjVmMjAwMDA3Il0mc2V0ZWM9TkROa1pUYzVNekEyWm1SaE1EbGpOelUzWVdFME9UTmpNRFZoTjJJMU1XRT0~]]></Impression><Impression><![CDATA[https://sync.search.spotxchange.com/audience_sync/7?spotx_push=1&spotx_audience_id=2c8c9fad-400e-11e8-ae3c-132f5f200007&redir=https%3A%2F%2Fbcp.crwdcntrl.net%2Fmap%2Fc%3D4914%2Ftp%3DSPXC%2Ftpid%3D2c8c9fad-400e-11e8-ae3c-132f5f200007]]></Impression><Impression><![CDATA[http://b.scorecardresearch.com/b?c1=1&c2=6272977&c3=224046&cv=1.3&cj=1]]></Impression><Impression><![CDATA[https://sb.scorecardresearch.com/p?c1=2&c2=6272977&ns_ap_sv=2.1511.10&ns_type=hidden&ns_st_it=a&ns_st_sv=4.0.0&ns_st_ad=1&ns_st_sq=1&ns_st_id=1524561702227635&ns_st_ec=1&ns_st_cn=1&s_st_ev=play&ns_st_ct=va&ns_st_cl=0&ns_st_pt=0&c3=1cc70.0803c.de68&c4=1cc70.0803c.de68&c6=7025&ns_ts=1524561702227635]]></Impression><Creatives><Creative sequence=\"1\"><Linear><Duration>00:00:06</Duration><TrackingEvents><Tracking event=\"thirdQuartile\"><![CDATA[https://search.spotxchange.com/beacon?_a=224046&_p=1cc70.0803c.de68&_z=1&_m=eNpNTl1Lw0AQvN%2Byz0VuN5e9S8AHoRGEJP0wRVIp4TQX2hJsSRMq1v51Na1FOw%2FzMLMzs%2BpGSiEE%2BqR8Ri1JOGZ2JQZKW4nojFWVwrI06FhLKbUgUlKxeEjFKYjaaBJfZ4h0Fse%2FhOK7x5VwpgNUm%2B6thLBtOjeA0rYWwgO89Frtil27aVzX1BDC8914XDxmo2lUzKbxAgZgt9vicrfqC4A9ZvKD3vlTi6XdLXvLkl8FzpANyDPkNGqrjK8kMRquZHWdOW39Vy%2FgeLz8%2F5lTtE%2BeJt58Xdd5lr%2Bn2UzOh6%2BY0P0qX0de%2BhF5o2Gyz2ly%2BwPbH2KD&_l=eNptj01rwkAQhve37LnIzH4kq%2BBNKwF3e2plT2HdTKtttEET0Fj%2FezeVQinCzBze5znMiwyZTossDTCMMYcRGJBxVFFmWOFSWlGoE75wyScXvt5WfMKTBZhp%2FsCbcP7s2t9IST2Ex4b2%2F7RuXW9jSae4Cfs3Kl%2BJfjgagIRjdwgtVeUuHD6obeoQ6Y4LEvj1ytzzcnk7w%2BMsvZiNQaQeYFAruCHE3OTijwtDwUwpOf6y4nHjd4Vw4qW2vUe38Nr2896%2BR%2B1Xc7ALq55WxdnN%2FPQbzVdKgQ%3D%3D&_t=eNotUdty2jAQ9bfomQE7eCDxTB5IEzJpMKEpkDqlo5GlNVZiWxpJptAk%2F96VjR7O2d2jvWiVA%2BOqCWAyLaYij%2BMpC6MILllcxJEQlxEKYRhOA14y2QTK7FkjeZD3WR%2BkN6g7aSAJMcBbY2SzJwOiK3ZysvbhCboHKUDRA6ukoIU01tHCsE5FkQlqT9ZBTZIPYlzuiVcSGkct5pEkHBDbaq2MsxQvS0ESZ1rAslqS5DfZrmYPt1ioY%2Fr9J5rpKkacL7aIL3c3KdJs9q0LdZSuxh7jGeLTvcfnp8cN0nqL%2BX%2BwIS%2BhG1BpaHAoekEvUC4ABG1NhULpnLbJbrQb5VIM90Oh2rwCHJy%2FDxtwu9Exz6ETdyOrlTv2a3GFMnX%2FDFoyW5Kkaavqa0AEcwzL%2FrrB96FrgRleUquB%2B4Vo5hfmwFjvCThIDt6Co%2FPUNaB9mDKtz39yLl0rAVXvDYiy5zieIIiGYRgsN4tFEE3ieHz1ufz38Dd7ew9fX%2BYyvZ%2FX6RuPs%2FWPU1bfRentUr7WmzBbZ%2BO03lz%2FBygdubI%3D&_b=eNozYfAL9fFBI2r8w12NI3N9TfyyHE39QzKyorIcDfxcko19qxxNfF2CsiOznDL9XPyyfatCbQFnrxOe&beacon_type=recurring&view_percent=75]]></Tracking><Tracking event=\"midpoint\"><![CDATA[https://search.spotxchange.com/beacon?_a=224046&_p=1cc70.0803c.de68&_z=1&_m=eNpNTl1Lw0AQvN%2Byz0VuN5e9S8AHoRGEJP0wRVIp4TQX2hJsSRMq1v51Na1FOw%2FzMLMzs%2BpGSiEE%2BqR8Ri1JOGZ2JQZKW4nojFWVwrI06FhLKbUgUlKxeEjFKYjaaBJfZ4h0Fse%2FhOK7x5VwpgNUm%2B6thLBtOjeA0rYWwgO89Frtil27aVzX1BDC8914XDxmo2lUzKbxAgZgt9vicrfqC4A9ZvKD3vlTi6XdLXvLkl8FzpANyDPkNGqrjK8kMRquZHWdOW39Vy%2FgeLz8%2F5lTtE%2BeJt58Xdd5lr%2Bn2UzOh6%2BY0P0qX0de%2BhF5o2Gyz2ly%2BwPbH2KD&_l=eNptj01rwkAQhve37LnIzH4kq%2BBNKwF3e2plT2HdTKtttEET0Fj%2FezeVQinCzBze5znMiwyZTossDTCMMYcRGJBxVFFmWOFSWlGoE75wyScXvt5WfMKTBZhp%2FsCbcP7s2t9IST2Ex4b2%2F7RuXW9jSae4Cfs3Kl%2BJfjgagIRjdwgtVeUuHD6obeoQ6Y4LEvj1ytzzcnk7w%2BMsvZiNQaQeYFAruCHE3OTijwtDwUwpOf6y4nHjd4Vw4qW2vUe38Nr2896%2BR%2B1Xc7ALq55WxdnN%2FPQbzVdKgQ%3D%3D&_t=eNotUdty2jAQ9bfomQE7eCDxTB5IEzJpMKEpkDqlo5GlNVZiWxpJptAk%2F96VjR7O2d2jvWiVA%2BOqCWAyLaYij%2BMpC6MILllcxJEQlxEKYRhOA14y2QTK7FkjeZD3WR%2BkN6g7aSAJMcBbY2SzJwOiK3ZysvbhCboHKUDRA6ukoIU01tHCsE5FkQlqT9ZBTZIPYlzuiVcSGkct5pEkHBDbaq2MsxQvS0ESZ1rAslqS5DfZrmYPt1ioY%2Fr9J5rpKkacL7aIL3c3KdJs9q0LdZSuxh7jGeLTvcfnp8cN0nqL%2BX%2BwIS%2BhG1BpaHAoekEvUC4ABG1NhULpnLbJbrQb5VIM90Oh2rwCHJy%2FDxtwu9Exz6ETdyOrlTv2a3GFMnX%2FDFoyW5Kkaavqa0AEcwzL%2FrrB96FrgRleUquB%2B4Vo5hfmwFjvCThIDt6Co%2FPUNaB9mDKtz39yLl0rAVXvDYiy5zieIIiGYRgsN4tFEE3ieHz1ufz38Dd7ew9fX%2BYyvZ%2FX6RuPs%2FWPU1bfRentUr7WmzBbZ%2BO03lz%2FBygdubI%3D&_b=eNozZvAL9fFBI2r8srJN%2FENcjf1cnHIjQ6Jyo3J9q6LC%2FbJ9XVwrfKu8cn1dQg0ic%2F2AMNQWAHwnFGs%3D&beacon_type=recurring&view_percent=50]]></Tracking><Tracking event=\"firstQuartile\"><![CDATA[https://search.spotxchange.com/beacon?_a=224046&_p=1cc70.0803c.de68&_z=1&_m=eNpNTl1Lw0AQvN%2Byz0VuN5e9S8AHoRGEJP0wRVIp4TQX2hJsSRMq1v51Na1FOw%2FzMLMzs%2BpGSiEE%2BqR8Ri1JOGZ2JQZKW4nojFWVwrI06FhLKbUgUlKxeEjFKYjaaBJfZ4h0Fse%2FhOK7x5VwpgNUm%2B6thLBtOjeA0rYWwgO89Frtil27aVzX1BDC8914XDxmo2lUzKbxAgZgt9vicrfqC4A9ZvKD3vlTi6XdLXvLkl8FzpANyDPkNGqrjK8kMRquZHWdOW39Vy%2FgeLz8%2F5lTtE%2BeJt58Xdd5lr%2Bn2UzOh6%2BY0P0qX0de%2BhF5o2Gyz2ly%2BwPbH2KD&_l=eNptj01rwkAQhve37LnIzH4kq%2BBNKwF3e2plT2HdTKtttEET0Fj%2FezeVQinCzBze5znMiwyZTossDTCMMYcRGJBxVFFmWOFSWlGoE75wyScXvt5WfMKTBZhp%2FsCbcP7s2t9IST2Ex4b2%2F7RuXW9jSae4Cfs3Kl%2BJfjgagIRjdwgtVeUuHD6obeoQ6Y4LEvj1ytzzcnk7w%2BMsvZiNQaQeYFAruCHE3OTijwtDwUwpOf6y4nHjd4Vw4qW2vUe38Nr2896%2BR%2B1Xc7ALq55WxdnN%2FPQbzVdKgQ%3D%3D&_t=eNotUdty2jAQ9bfomQE7eCDxTB5IEzJpMKEpkDqlo5GlNVZiWxpJptAk%2F96VjR7O2d2jvWiVA%2BOqCWAyLaYij%2BMpC6MILllcxJEQlxEKYRhOA14y2QTK7FkjeZD3WR%2BkN6g7aSAJMcBbY2SzJwOiK3ZysvbhCboHKUDRA6ukoIU01tHCsE5FkQlqT9ZBTZIPYlzuiVcSGkct5pEkHBDbaq2MsxQvS0ESZ1rAslqS5DfZrmYPt1ioY%2Fr9J5rpKkacL7aIL3c3KdJs9q0LdZSuxh7jGeLTvcfnp8cN0nqL%2BX%2BwIS%2BhG1BpaHAoekEvUC4ABG1NhULpnLbJbrQb5VIM90Oh2rwCHJy%2FDxtwu9Exz6ETdyOrlTv2a3GFMnX%2FDFoyW5Kkaavqa0AEcwzL%2FrrB96FrgRleUquB%2B4Vo5hfmwFjvCThIDt6Co%2FPUNaB9mDKtz39yLl0rAVXvDYiy5zieIIiGYRgsN4tFEE3ieHz1ufz38Dd7ew9fX%2BYyvZ%2FX6RuPs%2FWPU1bfRentUr7WmzBbZ%2BO03lz%2FBygdubI%3D&_b=eNozYvAL9fFBI2p8qxwNIrOyK6JCUnL8XUIr%2FEIyMiOz0iv83X0rfLOyTX2rko38XVwrIqsibQGT7hUz&beacon_type=recurring&view_percent=25]]></Tracking><Tracking event=\"complete\"><![CDATA[https://search.spotxchange.com/beacon?_a=224046&_p=1cc70.0803c.de68&_z=1&_m=eNpNTl1Lw0AQvN%2Byz0VuN5e9S8AHoRGEJP0wRVIp4TQX2hJsSRMq1v51Na1FOw%2FzMLMzs%2BpGSiEE%2BqR8Ri1JOGZ2JQZKW4nojFWVwrI06FhLKbUgUlKxeEjFKYjaaBJfZ4h0Fse%2FhOK7x5VwpgNUm%2B6thLBtOjeA0rYWwgO89Frtil27aVzX1BDC8914XDxmo2lUzKbxAgZgt9vicrfqC4A9ZvKD3vlTi6XdLXvLkl8FzpANyDPkNGqrjK8kMRquZHWdOW39Vy%2FgeLz8%2F5lTtE%2BeJt58Xdd5lr%2Bn2UzOh6%2BY0P0qX0de%2BhF5o2Gyz2ly%2BwPbH2KD&_l=eNptj01rwkAQhve37LnIzH4kq%2BBNKwF3e2plT2HdTKtttEET0Fj%2FezeVQinCzBze5znMiwyZTossDTCMMYcRGJBxVFFmWOFSWlGoE75wyScXvt5WfMKTBZhp%2FsCbcP7s2t9IST2Ex4b2%2F7RuXW9jSae4Cfs3Kl%2BJfjgagIRjdwgtVeUuHD6obeoQ6Y4LEvj1ytzzcnk7w%2BMsvZiNQaQeYFAruCHE3OTijwtDwUwpOf6y4nHjd4Vw4qW2vUe38Nr2896%2BR%2B1Xc7ALq55WxdnN%2FPQbzVdKgQ%3D%3D&_t=eNotUdty2jAQ9bfomQGbuJB6pg%2FQtJm02JC2QEPpaGRpjUVkSyPJFJLm37O20cM5u3u0F61yYFzXAUymxVTkcTxlYRTBLYuLOBLiNkIhDMNpwEsm60DbA6slD%2FI%2B65X0BvUXAyQhXFdGgQcyIEaxi5dVG52ge5ICND0xJQUtpHWeFpZ1KopMUHdxHiqSvBLr85a4klB76jCPJOGAuMYYbb2jeFkKknjbAJY1kiR%2FyGY1e7jDQh3Tbz%2FRTFcx4tfFBnH7ZZ4izWafu1BH6eqmxXiGuLxv8cfy%2Bxrp1wbz%2F2JDXkI3oDZQ41B0TMcoFwCCNlahUHpvXLIf7Ue5FMPDUOgmV4CD8%2BdhDX4%2FOuc5dOJ%2B5Iz2534tvtC26p9BS%2BZKktSNUm8DIphnWPb3HN%2BHrgNmeUmdAd4uxLB2YR6saz0BJ8mhteDsW%2Boa0D5MmTHXL7mWrrQA1XsDot01jicIomEYBtl6sQiiSRzffPz%2FdDxE2f3Dv7R6%2FLA7ztXybvf8dNxV2Yuosm16zrZZlY3XUfay%2FvQOKN25mg%3D%3D&_b=eNozZPAL9fFBI2ois8Iy%2FN2DcvyqPCsjq7KN%2FKqSjaNy3TKjXMIy%2FLKyTfyyXMsjszyNfLN8bQGSHxTj&beacon_type=complete]]></Tracking><Tracking event=\"firstQuartile\"><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=960584;]]></Tracking><Tracking event=\"midpoint\"><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=18;]]></Tracking><Tracking event=\"thirdQuartile\"><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=960585;]]></Tracking><Tracking event=\"complete\"><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=13;]]></Tracking><Tracking event=\"mute\"><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=16;]]></Tracking><Tracking event=\"unmute\"><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=149645;]]></Tracking><Tracking event=\"pause\"><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=15;]]></Tracking><Tracking event=\"fullscreen\"><![CDATA[https://ade.googlesyndication.com/ddm/activity/dc_oe=ChMI5Y7K9crS2gIVwUcrCh24mg4tEAAYACDfsOYv;met=1;ecn1=1;etm1=0;eid1=19;]]></Tracking><Tracking event=\"complete\"><![CDATA[https://event.spotxchange.com/vast/complete?_x=WzE1MjQ1NjE3MDIsImU2NjZlZDE5NDdhMDExZThhNGY0MWRkODFlNjcwMDA3IiwiMjI0MDQ2IiwiMWNjNzAuMDgwM2MuZGU2OCIsIjcwMjUiLCIxY2M3MC4wODAzYy5kZTY4IiwiMTA1NDIzNjg3Il0mc2V0ZWM9TURjM1pqVTNOR0kwTkRaaU56Y3dNMlJsWldNd1pHUmpNbVEwWXpJME9UTT0~]]></Tracking><Tracking event=\"firstQuartile\"><![CDATA[https://event.spotxchange.com/vast/25?_x=WzE1MjQ1NjE3MDIsImU2NjZlZDE5NDdhMDExZThhNGY0MWRkODFlNjcwMDA3IiwiMjI0MDQ2IiwiMWNjNzAuMDgwM2MuZGU2OCIsIjcwMjUiLCIxY2M3MC4wODAzYy5kZTY4IiwiMTA1NDIzNjg3Il0mc2V0ZWM9TURjM1pqVTNOR0kwTkRaaU56Y3dNMlJsWldNd1pHUmpNbVEwWXpJME9UTT0~]]></Tracking><Tracking event=\"midpoint\"><![CDATA[https://event.spotxchange.com/vast/50?_x=WzE1MjQ1NjE3MDIsImU2NjZlZDE5NDdhMDExZThhNGY0MWRkODFlNjcwMDA3IiwiMjI0MDQ2IiwiMWNjNzAuMDgwM2MuZGU2OCIsIjcwMjUiLCIxY2M3MC4wODAzYy5kZTY4IiwiMTA1NDIzNjg3Il0mc2V0ZWM9TURjM1pqVTNOR0kwTkRaaU56Y3dNMlJsWldNd1pHUmpNbVEwWXpJME9UTT0~]]></Tracking><Tracking event=\"thirdQuartile\"><![CDATA[https://event.spotxchange.com/vast/75?_x=WzE1MjQ1NjE3MDIsImU2NjZlZDE5NDdhMDExZThhNGY0MWRkODFlNjcwMDA3IiwiMjI0MDQ2IiwiMWNjNzAuMDgwM2MuZGU2OCIsIjcwMjUiLCIxY2M3MC4wODAzYy5kZTY4IiwiMTA1NDIzNjg3Il0mc2V0ZWM9TURjM1pqVTNOR0kwTkRaaU56Y3dNMlJsWldNd1pHUmpNbVEwWXpJME9UTT0~]]></Tracking><Tracking event=\"complete\"><![CDATA[https://sb.scorecardresearch.com/p?c1=2&c2=6272977&ns_ap_sv=2.1511.10&ns_type=hidden&ns_st_it=a&ns_st_sv=4.0.0&ns_st_ad=1&ns_st_sq=1&ns_st_id=1524561702227635&ns_st_ec=2&ns_st_cn=1&s_st_ev=end&ns_st_ct=va&ns_st_cl=0&ns_st_pt=0&c3=1cc70.0803c.de68&c4=1cc70.0803c.de68&c6=7025&ns_ts=1524561702227635]]></Tracking></TrackingEvents><VideoClicks><ClickThrough><![CDATA[https://search.spotxchange.com/click?_a=224046&_p=1cc70.0803c.de68&_z=1&_m=eNpNT2tPGzEQNH%2FFn8nh99mR%2BoEqQULKg0ICSqvIcuw1d4TcRXc5FRHy21snQS0r7UqenfXMiIwQhBCVTEhFc8IQKKUgUCNyRygF7UQUNARNQeWEkBwxJohQ6HaCKJOZMRmTMqMJWXVVeIX%2B1dWv67s7%2B30%2BGYyGS7THXQuNfe7KgPtYm0hX3HMWA6HcKAI%2BgOQ%2BCa28cwFfnullayv4nQ4S4Ot6XYIN9caVVYJacI0vsnZb79584apnyHy9SUTXhRIqD%2FYkxbz2JrrQE4RA7xil54D7Hk3iMjJyDIMPiNJc5wxdoMl8NDoPiv6k%2BgKcxh7HOiXE%2FV3TwSUObudwf4%2FPqW27qxvomtckfIr%2FMJveD%2B38frQ8Gttu7SfvZE1xpZg0afMPtYVri7RyTEYDmjnDuGaQ09wJLQVhimoVSfx6c9T6%2F%2FUSHw6f%2Fj%2FGm8f14v1mMx5MXn7Obul0di2mgzVP72LxNOSLl4VM%2FTae%2Ffj2F3dFmJM%3D&_l=eNptjltLw0AQhfe37LOks0k2uyn4JpRCk1K12vQlTHYnGtu0IRfsxf53E4sgKsOch3M%2BOEcwwWT%2Fgg1ijAIHNHjGsRTov8Y0ZsAs4banz9zj4zPPCsvHvKdABJLf8AqP%2B679tnxPDmZT0e4X1mXbwqR0MK%2B4e6E0J%2FrKhQboY9PV2JJNS6w31FZbNPQPCx7wy4XFy9nsKv2sh2rfrq4gG5Z0GTlmX466huqRQZt19VE2LdbFzhbI0JJGRJmFUvo6U0blrgd%2BHshAuQJypsCVLAgHFaCF9OFaJYTSyv3RDf2JwPe98GP%2BvICkXLrzu6fN%2BjGR88lSRqfFMZokELnRe%2FJ2X8an6LAup7efWAJqWQ%3D%3D&_t=eNpFjM1ugzAQhP0sPkfVOlg4OOqtP2ql0AttlVyQYxziBLCF3ZaE8u41oCp72Z1vZ0ZWWp6RitmBFXtKmQBC1ErQAyVFsSLhAQAMyaPQDTJtKRotkZxCPXZKtPKYO6sk5j22ohW18qp1oyrUt5ZqvFTnx%2BWs8V0%2B41xYm%2FuLDf%2FlsMC1KVSFOSywCVkYwiBE7gCQ4Iz3jsccl5XZiwqvNYf1BKxx%2FgYijnUtRhVRFidJQJRjqf1lZEuWwHKOtarUpvmHJEAWfOar8e1kJRDNdcVcB%2BsBkZjSKPndfb7A2%2FNTvTnt9O7h9Zxew87ef9Kr7LbZhmyzD705lV2aPd7%2FASoPaxw%3D&_b=eNo1U8mOq0gAe1%2FTN7rZIU9qjSBh67AGAoRLBMUOAVJUEUDz8ZN5o%2FHJli1ZPpj8VSM0zb%2B%2FvtIc9A3oPqvPfMRZX%2FynhgJ9TWD%2B%2BqP%2BWtPmWzpLTjtjKGyML5FgfQ5hmRmTYpCruq3k5ZkOoMroaU%2BVxMtPdSCc%2FOdsdcKx0MwX200DaXalbbqGFdHcvpz4vWB99hW6UDwT5bWbRULbcVmaj3o7aKrHX5kMgyQ0MHQUJeLpjjzdnTTyvTTvVGueqs0vM3AIcjcOOm9Ym25HvrAId8Ab%2FEsLspmvSI9d706sp%2BOzi2wmrinTYBJhIlSwkYr0fK3RI45rs3QOk8sNT3DDCT0G7lbBu6%2FH0PGfoDAkIULtlP%2BEDtQnetXKUEt%2FzB1hhjRpJAwwGMM2kmbI2PdTq%2BzjZpuDIR0kOshYytXdbZyGwu85ahCm61ZFJa3cWagXHTp0R%2By%2FxlPfQpJqdDfa0oJ4bHI8TKJAE33GMo%2FcNjw9KethBVFe5O6QmXJw9O%2FB7JeiH6kdeghESen2HCV%2BI9WLlmrBcPB5l%2FIJDjKj7d2GQRdsMcOb5TVpQtns9Rm8ohXVxxujbh04TUWELNSeBXFQcOiSgs9bmMeiSlxDO%2Bgm%2B8CMDcthI5F8fWOGBGi3qqSb2x4rbHsBoH6Xssv1MIaaUlpXEFryhsaRfaWXibBnTqSL9sjldGMu9kUcFXTx5lJ2FrRzjWEyJx6yXH2Qc4sR0uI8zuId9pbucXzHP4AqmPHROwU86uToh8CtGsfAAY%2Bc2Qeywtq%2B9F7jvpbDol4AQtRjuVynOzxPHYVMQSRVszXC1rSu1ZSVZSIaQavfOrMgIJgIVqkdZlnGJRthhBRhwNojXog49iS0hrcEMRDesv0Bzqvxkvvlh6ezQucy72P%2B9xhW2RO34CyACzPRiVhfFdxvuzx5Hi5Y9XglEK%2FYHebWcGy11Bjvhy1ES2lvoK5WtVvhnLJzEGbD3f2J5VsXiiFWZeTbxJaPzjhtsj2913S2eW7DNTo5sV0enrsq6%2F09Cp6sH4R%2BdlQ%2B5qb6PlakBM8%2F%2Fi5xjfywYhg9BUVSPjDsy2b9pj7S%2FE2%2F%2Fz%2F%2F6%2FX63EaMcFZ8gvHxhecCfoE0zzDcuBmlsBnyJv1lX03zV8ELZc6xJSukJEUVYvqmVJ6L1NtQ3%2FiT%2BtvRvNXe%2Bz6JrN06VbulKaS9g9VqFcoKOvq2V4yl2b0VKd%2F%2FAOocivs%3D]]></ClickThrough></VideoClicks><MediaFiles><MediaFile delivery=\"progressive\" type=\"video/mp4\" bitrate=\"391\" width=\"480\" height=\"270\" scalable=\"false\" maintainAspectRatio=\"false\"><![CDATA[https://gcdn.2mdn.net/videoplayback/id/fa46c0dde0076dea/itag/342/source/doubleclick_dmm/ratebypass/yes/acao/yes/ip/0.0.0.0/ipbits/0/expire/3668050536/sparams/id,itag,source,ratebypass,acao,ip,ipbits,expire/signature/634B63F3E5F1D1970FE9369548A285BEEFE3E501.30D591C60782C7ECC5B39DACEBABCB68B673B631/key/ck2/file/file.mp4]]></MediaFile><MediaFile delivery=\"progressive\" type=\"video/mp4\" bitrate=\"500\" width=\"854\" height=\"480\" scalable=\"false\" maintainAspectRatio=\"false\"><![CDATA[https://gcdn.2mdn.net/videoplayback/id/fa46c0dde0076dea/itag/59/source/doubleclick_dmm/ratebypass/yes/acao/yes/ip/0.0.0.0/ipbits/0/expire/3668050540/sparams/id,itag,source,ratebypass,acao,ip,ipbits,expire/signature/B6883DDE53D6618AFE846561CC5219A773D6637F.11526DB7A3DB9E684273A47978AF4576AE3AA23E/key/ck2/file/file.mp4]]></MediaFile><MediaFile delivery=\"progressive\" type=\"video/mp4\" bitrate=\"696\" width=\"720\" height=\"406\" scalable=\"false\" maintainAspectRatio=\"false\"><![CDATA[https://gcdn.2mdn.net/videoplayback/id/fa46c0dde0076dea/itag/346/source/doubleclick_dmm/ratebypass/yes/acao/yes/ip/0.0.0.0/ipbits/0/expire/3668050536/sparams/id,itag,source,ratebypass,acao,ip,ipbits,expire/signature/7399247DF2540556D51562C75ABC520BD6692F35.B13BC6FA86EF1139E91FA497E0D9D46145E28F6B/key/ck2/file/file.mp4]]></MediaFile><MediaFile delivery=\"progressive\" type=\"video/mp4\" bitrate=\"936\" width=\"1280\" height=\"720\" scalable=\"false\" maintainAspectRatio=\"false\"><![CDATA[https://gcdn.2mdn.net/videoplayback/id/fa46c0dde0076dea/itag/22/source/doubleclick_dmm/ratebypass/yes/acao/yes/ip/0.0.0.0/ipbits/0/expire/3668050541/sparams/id,itag,source,ratebypass,acao,ip,ipbits,expire/signature/31CCBDEDF87CEAC0D2A6E2B8314B9BF9B6C5FB71.4D58739AFE64B64499EDFCC536A901316DDC29D8/key/ck2/file/file.mp4]]></MediaFile><MediaFile delivery=\"progressive\" type=\"video/mp4\" bitrate=\"966\" width=\"640\" height=\"360\" scalable=\"false\" maintainAspectRatio=\"false\"><![CDATA[https://gcdn.2mdn.net/videoplayback/id/fa46c0dde0076dea/itag/343/source/doubleclick_dmm/ratebypass/yes/acao/yes/ip/0.0.0.0/ipbits/0/expire/3668050538/sparams/id,itag,source,ratebypass,acao,ip,ipbits,expire/signature/B409375096BAF5DB3EA2BAAA2756B030E23CF19E.B6EFA502E6D9FD02843A581E48CC3E3525446F87/key/ck2/file/file.mp4]]></MediaFile><MediaFile delivery=\"progressive\" type=\"video/mp4\" bitrate=\"1186\" width=\"640\" height=\"360\" scalable=\"false\" maintainAspectRatio=\"false\"><![CDATA[https://gcdn.2mdn.net/videoplayback/id/fa46c0dde0076dea/itag/344/source/doubleclick_dmm/ratebypass/yes/acao/yes/ip/0.0.0.0/ipbits/0/expire/3668050537/sparams/id,itag,source,ratebypass,acao,ip,ipbits,expire/signature/AF1D7230232C9E0E4378D9439F2196FB55A97E40.9C73211E840AEEFFB35AA43F12AD79C35176787F/key/ck2/file/file.mp4]]></MediaFile><MediaFile delivery=\"progressive\" type=\"video/mp4\" bitrate=\"1432\" width=\"1024\" height=\"576\" scalable=\"false\" maintainAspectRatio=\"false\"><![CDATA[https://gcdn.2mdn.net/videoplayback/id/fa46c0dde0076dea/itag/347/source/doubleclick_dmm/ratebypass/yes/acao/yes/ip/0.0.0.0/ipbits/0/expire/3668050539/sparams/id,itag,source,ratebypass,acao,ip,ipbits,expire/signature/584CEC7C7471B1CF2A6EBC5A6D7DDB4C5CBD15D3.A1442BDE9C2C25FFD8C68F985375DD9784BDB72F/key/ck2/file/file.mp4]]></MediaFile></MediaFiles></Linear></Creative></Creatives><Extensions><Extension type=\"LR-Pricing\"><Price model=\"CPM\" currency=\"USD\" source=\"spotxchange\"><![CDATA[1.4355]]></Price></Extension><Extension type=\"SpotX-Count\"><total_available><![CDATA[2]]></total_available></Extension><Extension><AdVerifications><Verification vendor=\"Moat\"><ViewableImpression id=\"zMoatPublisherID=117872 zMoatChannelID=224046 zMoatAdvertiserID=7025 zMoatCampaignID=1cc70.0803c.de68 zMoatSpotXDomain=unknown zMoatBundleID=[app_bundle]\"><![CDATA[https://px.moatads.com/pixel.gif?moatPartnerId=spotxpartnerid636191202359&moatPartnerKey=zMoatSpotXPc&moatNode=true]]></ViewableImpression></Verification></AdVerifications></Extension></Extensions></InLine></Ad></VAST>";

        String TAG_HTML_CREATIVE = " <script> parent.postMessage(\"pokktAdAvailable\", \"*\"); </script> <html> <body> <button type=\"button\" onclick=\"gratify()\">Click me</button> <script> function gratify() { if (typeof(Android) != \"undefined\" && Android.gratifyInterstitial) { Android.gratifyInterstitial(); }else{ if(window && window.external && window.external.notify) { window.external.notify(\"gratifyInterstitial\"); } } } </script> </body> </html> <img height=\"1\" width=\"1\" src='http://sg-tracker.pokkt.com/api/VideoEventTracker?birthday=&country=india&app_version=7.3.0&device_model=&categoryIab=&city=bengaluru&app_bundle_name=com.pokkt.ad.demo&latitude=0.0&screen=Default+screen+name...&skip=0&language=en&device_type=Phone&creative_id=21312&platform=android&device_name=android&eap=PT_EAP&mac_address=&appId=cc41e865391d6ea371b18aff27cc10e6&exdi=&sdk_version=7.3.0&adv_id=321&state=karnataka&deal_id=&carrier_name=Android&brand=Generic&campaign_id=6299&opt_userid=123456&timestamp=1531743495773&longitude=0.0&device_id=&connection_type=4G&appName=&ip=49.204.71.214&os_version=8.1.0&sex=&advertisingID=5701427f-ff71-4192-af4e-d8da3ee03733&partner_param=&vc=0.0&offer_id=14354&token=30eccdfec5d7b2c10ab47cd646d754f6&ad_id=&user_id=0&track_id=62978655-0eb1-4dd2-9627-6b4659f168dd&marketing_name=&channel_id=6168&encodedPubParams=testdata%3D%257B%2522adnetwork%2522%253A%2B%2522pokkt%2522%257D&event=6&r_type=img' style=\"display: none\" /> <img height=\"1\" width=\"1\" src='https://visitanalytics.userreport.com/hit.gif?t=ZOPe7ae77f8&ord=[Timestamp]' style=\"display: none\" /> <img height=\"1\" width=\"1\" src='http://bs.serving-sys.com/BurstingPipe/adServer.bs?cn=tf&c=19&mc=imp&pli=18431891&PluID=0&ord=1531743495&rtu=-1' style=\"display: none\" /> <img height=\"1\" width=\"1\" src='https://adrta.com/i?clid=pkt&paid=pkt&dvid=v&avid=321&caid=6299&plid=1435421312&publisherId=cc41e865391d6ea371b18aff27cc10e6&kv1=1080X1794&kv4=49.204.71.214&kv11=153174349596131&kv18=com.pokkt.ad.demo&kv16=0.0&kv17=0.0&kv19=5701427f-ff71-4192-af4e-d8da3ee03733&kv23=Android&kv26=android&kv25=&kv27=Dalvik%2F2.1.0+%28Linux%3B+U%3B+Android+8.1.0%3B+Android+SDK+built+for+x86+Build%2FOSM2.171116.002%29&kv24=Mobile_InApp_Video;' style=\"display: none\" /> <script src=\"https://pokktjs.pokkt.com/scripts/jquery.min.js\"></script> <script> function fireTracker(url) { $.ajax({ url: url }); } var tPCU = '%%click_track_url%%'; var listener = function(){ fireTracker(\"http://sg-vdo.pokkt.com/api/redirect?birthday=&country=india&app_version=7.3.0&device_model=&categoryIab=&city=bengaluru&app_bundle_name=com.pokkt.ad.demo&latitude=0.0&screen=Default+screen+name...&skip=0&language=en&device_type=Phone&creative_id=21312&platform=android&device_name=android&eap=PT_EAP&mac_address=&appId=cc41e865391d6ea371b18aff27cc10e6&exdi=&sdk_version=7.3.0&adv_id=321&state=karnataka&deal_id=&carrier_name=Android&brand=Generic&campaign_id=6299&opt_userid=123456&timestamp=1531743495802&longitude=0.0&device_id=&connection_type=4G&appName=&ip=49.204.71.214&os_version=8.1.0&sex=&advertisingID=5701427f-ff71-4192-af4e-d8da3ee03733&partner_param=&vc=0.0&offer_id=14354&token=c27792e72eaebea3d6bd68da0b7b4be7&ad_id=&user_id=0&track_id=62978655-0eb1-4dd2-9627-6b4659f168dd&marketing_name=&channel_id=6168&&CTH=&CT=http%3A%2F%2Fsg-tracker.pokkt.com%2Fapi%2FVideoEventTracker%3Fbirthday%3D%26country%3Dindia%26app_version%3D7.3.0%26device_model%3D%26categoryIab%3D%26city%3Dbengaluru%26app_bundle_name%3Dcom.pokkt.ad.demo%26latitude%3D0.0%26screen%3DDefault%2Bscreen%2Bname...%26skip%3D0%26language%3Den%26device_type%3DPhone%26creative_id%3D21312%26platform%3Dandroid%26device_name%3Dandroid%26eap%3DPT_EAP%26mac_address%3D%26appId%3Dcc41e865391d6ea371b18aff27cc10e6%26exdi%3D%26sdk_version%3D7.3.0%26adv_id%3D321%26state%3Dkarnataka%26deal_id%3D%26carrier_name%3DAndroid%26brand%3DGeneric%26campaign_id%3D6299%26opt_userid%3D123456%26timestamp%3D1531743495773%26longitude%3D0.0%26device_id%3D%26connection_type%3D4G%26appName%3D%26ip%3D49.204.71.214%26os_version%3D8.1.0%26sex%3D%26advertisingID%3D5701427f-ff71-4192-af4e-d8da3ee03733%26partner_param%3D%26vc%3D0.0%26offer_id%3D14354%26token%3D30eccdfec5d7b2c10ab47cd646d754f6%26ad_id%3D%26user_id%3D0%26track_id%3D62978655-0eb1-4dd2-9627-6b4659f168dd%26marketing_name%3D%26channel_id%3D6168%26encodedPubParams%3Dtestdata%253D%25257B%252522adnetwork%252522%25253A%252B%252522pokkt%252522%25257D%26event%3D9\"); if(typeof(tPCU) !== \"undefined\" && tPCU !== '%%click_track_url%%' && tPCU !== ''){ fireTracker(tPCU); } }; document.addEventListener(\"click\", listener, true); setTimeout(function () { fireTracker(\"http://sg-tracker.pokkt.com/api/VideoEventTracker?birthday=&country=india&app_version=7.3.0&device_model=&categoryIab=&city=bengaluru&app_bundle_name=com.pokkt.ad.demo&latitude=0.0&screen=Default+screen+name...&skip=0&language=en&device_type=Phone&creative_id=21312&platform=android&device_name=android&eap=PT_EAP&mac_address=&appId=cc41e865391d6ea371b18aff27cc10e6&exdi=&sdk_version=7.3.0&adv_id=321&state=karnataka&deal_id=&carrier_name=Android&brand=Generic&campaign_id=6299&opt_userid=123456&timestamp=1531743495802&longitude=0.0&device_id=&connection_type=4G&appName=&ip=49.204.71.214&os_version=8.1.0&sex=&advertisingID=5701427f-ff71-4192-af4e-d8da3ee03733&partner_param=&vc=0.0&offer_id=14354&token=c27792e72eaebea3d6bd68da0b7b4be7&ad_id=&user_id=0&track_id=62978655-0eb1-4dd2-9627-6b4659f168dd&marketing_name=&channel_id=6168&encodedPubParams=testdata%3D%257B%2522adnetwork%2522%253A%2B%2522pokkt%2522%257D&event=40\"); }, 1000) </script>";

        String TAG_HTML_CREATIVE_2 = "<!DOCTYPE HTML> <html> <head> <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" /> <meta name=\"viewport\" content=\"width=device-width, initial-scale=1, maximum-scale=1\"> <title>Showcase: Yamaha R3</title> <link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"\" /> <link rel=\"stylesheet\" href=\"https://s3-ap-southeast-1.amazonaws.com/endcards/css/r15_style.css\"> <style type=\"text/css\"> @-moz-document url-prefix() { .social-logo-wrapper { -webkit-clip-path: url(\"#clip-shape\"); clip-path: url(\"#clip-shape\"); } } </style> <script type=\"text/javascript\" src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/js/jquery.js\"></script> <script type=\"text/javascript\" src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/js/core.js\"></script> </head> <body> <div class=\"wrapper\" > <div style=\"height: 100%; cursor: pointer;\" onclick=\"window.location.href='http://www.yamaha-motor.co.th/automotive/product.php/type/street/title/Yamaha-YZF-R15-2016'\"> <h1> <a href=\"http://www.yamaha-motor.co.th/automotive/product.php/type/street/title/Yamaha-YZF-R15-2016\"><img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/logo.png\"></a> </h1> <h2><a href=\"http://www.yamaha-motor.co.th/automotive/product.php/type/street/title/Yamaha-YZF-R15-2016\"><img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/r15_title.png\"></a></h2> <div class=\"bike\"> <a href=\"http://www.yamaha-motor.co.th/automotive/product.php/type/street/title/Yamaha-YZF-R15-2016\"> <img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/r15_bike.png\" class=\"normalscreen\"> <img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/r15_bike-wide.png\" class=\"widescreen\"> </a> </div> </div> <div class=\"button-wrapper\"> <div class=\"social-block\"> <h5>www.yamaha-motor.co.th</h5> <div class=\"social-block-inner social-logo-wrapper\"> <a href=\"https://www.facebook.com/YamahaApps\" onclick=\"sendevent(57)\" target=\"_blank\"><img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/fb.png\"></a> <a href=\"https://www.instagram.com/yamahasocietythailand/\" onclick=\"sendevent(58)\" target=\"_blank\"><img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/instagram.png\"></a> <a href=\"https://www.youtube.com/user/THAIYAMAHAOFFICIAL\" onclick=\"sendevent(59)\" target=\"_blank\"><img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/youtube.png\"></a> </div> <p>Yamaha Society Thailand</p> </div> <!-- <a href=\"http://maps.google.com/maps?q=12.9136110,77.6286010\" class=\"shop-btn\" onclick=\"sendevent(60)\" target=\"_blank\"><img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/store.png\"></a> --> <a href=\"http://maps.google.com/?q=yamaha+stores+near+me\" class=\"shop-btn\" onclick=\"sendevent(60)\" target=\"_blank\"><img src=\"https://s3-ap-southeast-1.amazonaws.com/endcards/img/store.png\"></a> </div> <!-- #button-wrapper --> <svg width=\"0\" height=\"0\"> <defs> <clipPath id=\"clip-shape\" clipPathUnits=\"objectBoundingBox\"> <polygon points=\"0 0, 1 0, 1 1, 0.95 1, 0.95 0.95, 0.05 0.95, 0.05 1, 0 1\" /> </clipPath> </defs> </svg> </div> <script type=\"text/javascript\"> function sendevent(event_id){ var url = \"http://vdopokktfeed.pokkt.com/api/VideoEventTracker?appId=a2717a45b835b5e9f50284a38d62a74e&offer_id=6830&track_id=\"+(Math.floor((Math.random() * 10000000000000000)))+\"&timestamp=\"+Date.now()+\"&event=\"+event_id; var xhttp = new XMLHttpRequest(); xhttp.open(\"GET\", url, true); xhttp.send(); } </script> </body> </html>";

        String TAG_HTML_CREATIVE_3 = " <script> parent.postMessage(\"pokktAdAvailable\", \"*\"); </script> <html> <head> </head> <body> <a href=\"https://www.fastrack.in/sexybacks/?utm_source=Pokkt&utm_medium=Banners&utm_campaign=Fastrack%20Sexy%20Back%20-%20Pokkt%20Banners\"> <img src=\"https://d2h452d9fuy6ob.cloudfront.net/iurl_file/1495197764.jpg\" width=\"320\" height=\"480\" /></a> </body> </html> <img height=\"1\" width=\"1\" src='https://sg-tracker.pokkt.com/api/VideoEventTracker?birthday=&country=india&app_version=1.0&device_model=&categoryIab=&city=bengaluru&app_bundle_name=com.pokkt.&latitude=0.0&screen=Default&skip=0&language=en&device_type=iPhone&creative_id=14551&platform=ios&device_name=ios&eap=2.0&mac_address=&appId=55b38d841fbbcafe4d5a70d1bfcab3ba&exdi=&sdk_version=7.3.0&adv_id=321&state=karnataka&deal_id=&carrier_name=Beam+Telecom&brand=Apple&campaign_id=6299&opt_userid=&timestamp=1531909567916&longitude=0.0&device_id=&connection_type=WIFI&appName=&ip=49.204.71.215&os_version=9.0&sex=&advertisingID=744EF010-4933-45F8-87EC-89E30013AC24&partner_param=&vc=0.0&offer_id=9674&token=02c4457f373e5220e4f561abff1bb229&ad_id=&user_id=0&track_id=f949715b-11eb-4b47-8cf8-60aedafa9602&marketing_name=&channel_id=7904&encodedPubParams=&event=6&r_type=img' style=\"display: none\" /> <img height=\"1\" width=\"1\" src='https://adrta.com/i?clid=pkt&paid=pkt&dvid=v&avid=321&caid=6299&plid=967414551&publisherId=55b38d841fbbcafe4d5a70d1bfcab3ba&kv1=320X568&kv4=49.204.71.215&kv11=153190956775593&kv18=com.pokkt.&kv16=0.0&kv17=0.0&kv19=744EF010-4933-45F8-87EC-89E30013AC24&kv23=Beam Telecom&kv26=ios&kv25=&kv27=Mozilla%2F5.0+%28iPhone%3B+CPU+iPhone+OS+9_0+like+Mac+OS+X%29+AppleWebKit%2F601.1.46+%28KHTML%2C+like+Gecko%29+Mobile%2F13G34&kv24=Mobile_InApp_Video;' style=\"display: none\" /> <script src=\"https://pokktjs.pokkt.com/scripts/jquery.min.js\"></script> <script> function fireTracker(url) { $.ajax({ url: url }); } var tPCU = '%%click_track_url%%'; var listener = function(){ fireTracker(\"https://sg-vdo.pokkt.com/api/redirect?birthday=&country=india&app_version=1.0&device_model=&categoryIab=&city=bengaluru&app_bundle_name=com.pokkt.&latitude=0.0&screen=Default&skip=0&language=en&device_type=iPhone&creative_id=14551&platform=ios&device_name=ios&eap=2.0&mac_address=&appId=55b38d841fbbcafe4d5a70d1bfcab3ba&exdi=&sdk_version=7.3.0&adv_id=321&state=karnataka&deal_id=&carrier_name=Beam+Telecom&brand=Apple&campaign_id=6299&opt_userid=&timestamp=1531909567918&longitude=0.0&device_id=&connection_type=WIFI&appName=&ip=49.204.71.215&os_version=9.0&sex=&advertisingID=744EF010-4933-45F8-87EC-89E30013AC24&partner_param=&vc=0.0&offer_id=9674&token=52bb4e37a8a083b7ab534783c68e966b&ad_id=&user_id=0&track_id=f949715b-11eb-4b47-8cf8-60aedafa9602&marketing_name=&channel_id=7904&&CTH=&CT=https%3A%2F%2Fsg-tracker.pokkt.com%2Fapi%2FVideoEventTracker%3Fbirthday%3D%26country%3Dindia%26app_version%3D1.0%26device_model%3D%26categoryIab%3D%26city%3Dbengaluru%26app_bundle_name%3Dcom.pokkt.%26latitude%3D0.0%26screen%3DDefault%26skip%3D0%26language%3Den%26device_type%3DiPhone%26creative_id%3D14551%26platform%3Dios%26device_name%3Dios%26eap%3D2.0%26mac_address%3D%26appId%3D55b38d841fbbcafe4d5a70d1bfcab3ba%26exdi%3D%26sdk_version%3D7.3.0%26adv_id%3D321%26state%3Dkarnataka%26deal_id%3D%26carrier_name%3DBeam%2BTelecom%26brand%3DApple%26campaign_id%3D6299%26opt_userid%3D%26timestamp%3D1531909567916%26longitude%3D0.0%26device_id%3D%26connection_type%3DWIFI%26appName%3D%26ip%3D49.204.71.215%26os_version%3D9.0%26sex%3D%26advertisingID%3D744EF010-4933-45F8-87EC-89E30013AC24%26partner_param%3D%26vc%3D0.0%26offer_id%3D9674%26token%3D02c4457f373e5220e4f561abff1bb229%26ad_id%3D%26user_id%3D0%26track_id%3Df949715b-11eb-4b47-8cf8-60aedafa9602%26marketing_name%3D%26channel_id%3D7904%26encodedPubParams%3D%26event%3D9\"); if(typeof(tPCU) !== \"undefined\" && tPCU !== '%%click_track_url%%' && tPCU !== ''){ fireTracker(tPCU); } }; document.addEventListener(\"click\", listener, true); setTimeout(function () { fireTracker(\"https://sg-tracker.pokkt.com/api/VideoEventTracker?birthday=&country=india&app_version=1.0&device_model=&categoryIab=&city=bengaluru&app_bundle_name=com.pokkt.&latitude=0.0&screen=Default&skip=0&language=en&device_type=iPhone&creative_id=14551&platform=ios&device_name=ios&eap=2.0&mac_address=&appId=55b38d841fbbcafe4d5a70d1bfcab3ba&exdi=&sdk_version=7.3.0&adv_id=321&state=karnataka&deal_id=&carrier_name=Beam+Telecom&brand=Apple&campaign_id=6299&opt_userid=&timestamp=1531909567918&longitude=0.0&device_id=&connection_type=WIFI&appName=&ip=49.204.71.215&os_version=9.0&sex=&advertisingID=744EF010-4933-45F8-87EC-89E30013AC24&partner_param=&vc=0.0&offer_id=9674&token=52bb4e37a8a083b7ab534783c68e966b&ad_id=&user_id=0&track_id=f949715b-11eb-4b47-8cf8-60aedafa9602&marketing_name=&channel_id=7904&encodedPubParams=&event=40\"); }, 1000) </script>";

        String TAG_HTML_CREATIVE_TEST= "<html>  <script type=\"text/javascript\" src=\"mraid.js\"></script>\n" +
                "<img id=\"adTagLoadedPixel_215608\" src=\"https://stats.justad.mobi/tracking/detailed/et.php?eventType=12&adId=215608&{timestamp}\" style=\"visibility:hidden; display:none;\"></img>\n" +
                "\n" +
                "<div id=\"JA_Creative\">\n" +
                "<script type=\"text/javascript\">\n" +
                "\tvar adConfig = {\n" +
                " \t\tclickurl : '{clickurl}',\n" +
                "\t\tplatform : null,\n" +
                "\t\toptions  : {}\n" +
                " \t};\n" +
                "\tvar combinedMediaUrl = 'https://mediajustad-a.akamaihd.net/select/Mraid/215608?{timestamp}';\n" +
                "\t\n" +
                "\t\n" +
                "\t\n" +
                "\t\n" +
                "\tfunction downloadScript(src,adData) {\t\n" +
                "\t\t\tvar scp = document.createElement('script');\n" +
                "\t\t\tscp.src = src;\n" +
                "\t\t\tscp.onload = function() { launchAd(downloadScript,adData);};\n" +
                "\t\t\tdocument.getElementsByTagName('head')[0].appendChild(scp);\n" +
                "\t}\n" +
                "\tdownloadScript(combinedMediaUrl,adConfig);\n" +
                "</script>\n" +
                "</div>\n" +
                "</html>";

        edt_tag.setText(TAG_HTML_CREATIVE_TEST);
    }
}
