package com.pokkt.demo.fragments;

import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.pokkt.PokktAds;
import com.pokkt.ad.demo.R;
import com.pokkt.demo.PokktKotlinPluginKt;
import com.pokkt.demo.utility.Storage;
import com.pokkt.sdk.enums.IAPStoreType;
import com.pokkt.sdk.models.InAppPurchaseDetail;

public class PokktVideoFragment extends BaseFragment implements PokktAds.VideoAd.VideoAdDelegate {

    // ui
    private TextView txtScreenName;
    private EditText edtScreenName;
    private ProgressBar progressCacheRewarded, progressShowRewarded, progressCacheNonRewarded, progressShowNonRewarded;
    private Button btnCacheRewarded, btnShowRewarded, btnCacheNonRewarded, btnShowNonRewarded;
    private TextView txtEarnedPoints;
    private boolean testIAPTracker = false;//Make it true if you want to test IAP Tracker.

    public PokktVideoFragment() {
        // Required empty public constructor
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        // getArguments here
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.fragment_pokkt_video, container, false);

        // screen name
        txtScreenName = (TextView) findView(rootView, R.id.txt_screen_name);
        edtScreenName = (EditText) findView(rootView, R.id.edt_screen_name);
        edtScreenName.setContentDescription(getString(R.string.test_screenName));

        // earned points
        txtEarnedPoints = (TextView) findView(rootView, R.id.txt_earned_points);

        // cache rewarded
        progressCacheRewarded = (ProgressBar) findView(findView(rootView, R.id.btn_cache_rewarded), R.id.progressBar);
        btnCacheRewarded = (Button) findView(findView(rootView, R.id.btn_cache_rewarded), R.id.button);
        btnCacheRewarded.setContentDescription(getString(R.string.test_CacheRewardedVideoBtn));

        // show rewarded
        progressShowRewarded = (ProgressBar) findView(findView(rootView, R.id.btn_show_rewarded), R.id.progressBar);
        btnShowRewarded = (Button) findView(findView(rootView, R.id.btn_show_rewarded), R.id.button);
        btnShowRewarded.setContentDescription(getString(R.string.test_showRewardedVideoBtn));

        // cache non rewarded
        progressCacheNonRewarded = (ProgressBar) findView(findView(rootView, R.id.btn_cache_non_rewarded), R.id.progressBar);
        btnCacheNonRewarded = (Button) findView(findView(rootView, R.id.btn_cache_non_rewarded), R.id.button);
        btnCacheNonRewarded.setContentDescription(getString(R.string.test_CacheNonRewardedVideoBtn));

        // show non rewarded
        progressShowNonRewarded = (ProgressBar) findView(findView(rootView, R.id.btn_show_non_rewarded), R.id.progressBar);
        btnShowNonRewarded = (Button) findView(findView(rootView, R.id.btn_show_non_rewarded), R.id.button);
        btnShowNonRewarded.setContentDescription(getString(R.string.test_showNonRewardedVideoBtn));

        Toolbar toolbar = (Toolbar) rootView.findViewById(R.id.pokkttoolbar);
        toolbar.setNavigationOnClickListener(new View.OnClickListener(){
            @Override
            public void onClick(View view) {
                getActivity().onBackPressed();
            }
        });

        return rootView;
    }

    @Override
    public void onViewCreated(View view, Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        // setup data
        // screen name
        //setFont(edtScreenName);
        setFont(txtScreenName);

        // earned points
        txtEarnedPoints.setText(String.format(getString(R.string.txt_earned_points), String.valueOf(Storage.getVideoPoints(getActivity()))));
        setFont(txtEarnedPoints);

        // cache rewarded
        setFont(btnCacheRewarded);
        setProgressbarColor(progressCacheRewarded);
        btnCacheRewarded.setText(getString(R.string.txt_btn_cache_rewarded));
        btnCacheRewarded.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String screenName = edtScreenName.getText().toString().trim();
                if(Storage.isKotlin) {
                    if (!PokktKotlinPluginKt.isVideoAdCached(screenName, true)) {
                        progressCacheRewarded.setVisibility(View.VISIBLE);
                        if (isScreenNameSpecified()) {
                            PokktKotlinPluginKt.cacheRewardedVideo(screenName);
                        }
                    } else {
                        Toast.makeText(getActivity(), "Video Ad already cached", Toast.LENGTH_SHORT).show();
                    }
                } else {
                    if (!PokktAds.VideoAd.isAdCached(screenName, true)) {
                        progressCacheRewarded.setVisibility(View.VISIBLE);
                        if (isScreenNameSpecified()) {
                            PokktAds.VideoAd.cacheRewarded(screenName);
                        }
                    } else {
                        Toast.makeText(getActivity(), "Video Ad already cached", Toast.LENGTH_SHORT).show();
                    }
                }
            }
        });

        // show rewarded
        setFont(btnShowRewarded);
        setProgressbarColor(progressShowRewarded);
        btnShowRewarded.setText(getString(R.string.txt_btn_show_rewarded));
        btnShowRewarded.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                progressShowRewarded.setVisibility(View.VISIBLE);
                if (isScreenNameSpecified()) {
                    String screenName = edtScreenName.getText().toString().trim();
                    if(Storage.isKotlin) {
                        if (PokktKotlinPluginKt.isVideoAdCached(screenName, true)) {
                            Toast.makeText(getActivity(), "Video Ad is cached, Showing", Toast.LENGTH_SHORT).show();
                        }
                        PokktKotlinPluginKt.showRewardedVideo(screenName);
                    } else {
                        if (PokktAds.VideoAd.isAdCached(screenName, true)) {
                            Toast.makeText(getActivity(), "Video Ad is cached, Showing", Toast.LENGTH_SHORT).show();
                        }
                        PokktAds.VideoAd.showRewarded(screenName);
                    }
                }
            }
        });

        // cache non rewarded
        setFont(btnCacheNonRewarded);
        setProgressbarColor(progressCacheNonRewarded);
        btnCacheNonRewarded.setText(getString(R.string.txt_btn_cache_non_rewarded));
        btnCacheNonRewarded.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String screenName = edtScreenName.getText().toString().trim();
                if(Storage.isKotlin) {
                    if (!PokktKotlinPluginKt.isVideoAdCached(screenName, false)) {
                        progressCacheNonRewarded.setVisibility(View.VISIBLE);
                        if (isScreenNameSpecified()) {
                            PokktKotlinPluginKt.cacheNonRewardedVideo(screenName);
                        }
                    } else {
                        Toast.makeText(getActivity(), "Video Ad already cached", Toast.LENGTH_SHORT).show();
                    }
                } else {
                    if (!PokktAds.VideoAd.isAdCached(edtScreenName.getText().toString().trim(), false)) {
                        progressCacheNonRewarded.setVisibility(View.VISIBLE);
                        if (isScreenNameSpecified()) {
                            PokktAds.VideoAd.cacheNonRewarded(edtScreenName.getText().toString().trim());
                        }
                    } else {
                        Toast.makeText(getActivity(), "Video Ad already cached", Toast.LENGTH_SHORT).show();
                    }
                }
            }
        });

        // show non rewarded
        setFont(btnShowNonRewarded);
        setProgressbarColor(progressShowNonRewarded);
        btnShowNonRewarded.setText(getString(R.string.txt_btn_show_non_rewarded));
        btnShowNonRewarded.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                progressShowNonRewarded.setVisibility(View.VISIBLE);
                if (isScreenNameSpecified()) {
                    String screenName = edtScreenName.getText().toString().trim();
                    if (Storage.isKotlin) {
                        if (PokktKotlinPluginKt.isVideoAdCached(screenName, false)) {
                            Toast.makeText(getActivity(), "Video Ad is cached, Showing", Toast.LENGTH_SHORT).show();
                        }
                        PokktKotlinPluginKt.showNonRewardedVideo(screenName);
                    } else {
                        if (PokktAds.VideoAd.isAdCached(screenName, false)) {
                            Toast.makeText(getActivity(), "Video Ad is cached, Showing", Toast.LENGTH_SHORT).show();
                        }
                        PokktAds.VideoAd.showNonRewarded(screenName);
                    }
                }
            }
        });

        // OPTIONAL but we SUGGEST you to implement callbacks as it will help you to determine the status of your request
        if(Storage.isKotlin) {
            PokktKotlinPluginKt.setDelegate(this);
        } else {
            PokktAds.VideoAd.setDelegate(this);
        }
    }


    private boolean isScreenNameSpecified() {
        if (TextUtils.isEmpty(edtScreenName.getText())) {
            Toast.makeText(getActivity(), "Please Enter Screen Name or Zone ID", Toast.LENGTH_LONG).show();
            hideProgress();
            return false;
        }
        return true;
    }

    private void hideProgress() {
        progressCacheRewarded.setVisibility(View.GONE);
        progressShowRewarded.setVisibility(View.GONE);
        progressCacheNonRewarded.setVisibility(View.GONE);
        progressShowNonRewarded.setVisibility(View.GONE);
    }

    // Video Ad CallBacks

    @Override
    public void videoAdCachingCompleted(final String screenName, boolean isRewarded, final double reward) {
        if (getActivity() == null) {
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(getActivity(), "Video Ad Caching Completed ! Ad vc is: " + reward, Toast.LENGTH_SHORT).show();
                if (edtScreenName.getText().toString().trim().equals(screenName)) { // screen name check as our SDK supports multiple ad-requests,
                    // it will help in identifying response to which request has arrived
                    hideProgress();
                }
            }
        });
    }

    @Override
    public void videoAdCachingFailed(final String screenName, boolean isRewarded, final String errorMessage) {
        if (getActivity() == null) {
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(getActivity(), "Video Ad Download Error " + errorMessage, Toast.LENGTH_LONG).show();
                if (edtScreenName.getText().toString().trim().equals(screenName)) {
                    hideProgress();
                }
            }
        });
    }

    @Override
    public void videoAdDisplayed(String screenName, boolean isRewarded) {
        if (getActivity() == null) {
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                hideProgress();
                Toast.makeText(getActivity(), "Video Ad Displayed",Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public void videoAdFailedToShow(String screenName, boolean isRewarded, final String errorMessage) {
        if (getActivity() == null) {
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(getActivity(), "Video Ad Show Error " + errorMessage, Toast.LENGTH_LONG).show();
                hideProgress();
            }
        });
    }

    @Override
    public void videoAdClosed(String screenName, boolean isRewarded) {
        if (getActivity() == null) {
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                hideProgress();
                Toast.makeText(getActivity(), "Video Ad Closed", Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public void videoAdSkipped(String screenName, boolean isRewarded) {
        if (getActivity() == null) {
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
        hideProgress();
                Toast.makeText(getActivity(), "Video Ad Skipped", Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public void videoAdCompleted(String screenName, boolean isRewarded) {
        if (getActivity() == null) {
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                hideProgress();
                Toast.makeText(getActivity(), "Video Ad Completed", Toast.LENGTH_SHORT).show();
            }
        });
    }

    @Override
    public void videoAdGratified(String screenName, boolean isRewarded, final double reward) {
        if (getActivity() == null) {
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                if(testIAPTracker) {// only for Pokkt ( testing  by developer)
                    InAppPurchaseDetail details = new InAppPurchaseDetail();
                    details.setProductId("xxx");
                    details.setPrice((int) reward);
                    details.setCurrencyCode("INR");
                    details.setDescription("COINS");
                    details.setTitle("COIN");
                    details.setPurchaseData(null);
                    details.setPurchaseSignature(null);
                    details.setPurchaseStore(IAPStoreType.NONE);
                    if(Storage.isKotlin) {
                        PokktKotlinPluginKt.trackIAP(details);
                    } else {
                        PokktAds.Analytics.trackIAP(details);
                    }
                }
                Toast.makeText(getActivity(), "Points Earned " + reward, Toast.LENGTH_SHORT).show();
                Storage.storeVideoPoints(getActivity(), (float) reward);
                float val = Storage.getVideoPoints(getActivity());
                txtEarnedPoints.setText(String.format(getString(R.string.txt_earned_points), String.valueOf(val)));
            }
        });
    }

    @Override
    public void videoAdClicked(String screenName, boolean isRewarded) {
        if(getActivity() == null){
            return;
        }
        getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(getActivity(), "Video Ad Clicked", Toast.LENGTH_SHORT).show();
            }
        });
    }
}
